%global gohomepath helm.sh/helm
%global goipath %{gohomepath}/v3
%global git_commit 3a31588ad33fe3b89af5a2a54ee1d25bfe6eaa5e
%global git_dirty clean

Summary:        The Kubernetes Package Manager
Name:           helm
Version:        3.14.2
Release:        2%{?dist}
License:        Apache-2.0
URL:            https://github.com/helm/helm
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
# execute 'go mod vendor' under the source code path can generator vendor package
Source1:        helm-%{version}-vendor.tar.gz

Patch0:         add-loongarch-support.patch

BuildRequires:  golang >= 1.19 go-rpm-macros

%description
Helm is a tool for managing Kubernetes charts. Charts are packages of pre-configured Kubernetes resources.

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -p1 -a1

%build
export GOPATH=$PWD/.gopath
mkdir -p ${GOPATH}/src/%{gohomepath}
ln -sfn $PWD $GOPATH/src/%{goipath}

export K8S_MINOR=$(grep k8s.io/client-go go.mod | cut -d. -f3)
export CGO_ENABLED=0
export GOFLAGS="-mod=vendor"
export LDFLAGS=" -X %{goipath}/internal/version.gitCommit=%{git_commit} \
                 -X %{goipath}/pkg/lint/rules.k8sVersionMajor=1 \
                 -X %{goipath}/pkg/lint/rules.k8sVersionMinor=$K8S_MINOR \
                 -X %{goipath}/pkg/chartutil.k8sVersionMajor=1 \
                 -X %{goipath}/pkg/chartutil.k8sVersionMinor=$K8S_MINOR \
                 -X %{goipath}/internal/version.gitTreeState=%{git_dirty} "
%gobuild -o helm %{goipath}/cmd/helm

%install
install -p -Dm 0755 helm %{buildroot}/%{_bindir}/helm
install -d %{buildroot}%{_datarootdir}/bash-completion/completions
%{buildroot}/%{_bindir}/helm completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}
install -d %{buildroot}%{_datarootdir}/zsh_completion.d
%{buildroot}/%{_bindir}/helm completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}
install -d %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}/%{_bindir}/helm completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%check
# requires network
rm -v pkg/plugin/installer/*installer_test.go
rm -v pkg/engine/engine_test.go
rm -v pkg/lint/lint_test.go
GO111MODULE=on go test ./...

%files
%license LICENSE
%doc ADOPTERS.md CONTRIBUTING.md README.md SECURITY.md code-of-conduct.md
%{_bindir}/helm

%files bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files zsh-completion
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%files fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Thu Jun 06 2024 Liangliang Zhai <zhailiangliang@loongson.cn> - 3.14.2-2
- [Type] other
- [DESC] add longarch64 support

* Mon Mar 25 2024 jackeyji <jackeyji@tencent.com> - 3.14.2-1
- upgrade to 3.14.2 to fix CVE-2024-25620 and CVE-2024-26147

* Tue Sep 12 2023 jackeyji <jackeyji@tencent.com> - 3.12.3-1
- initial build
